from distutils.core import setup

setup(
    name='overbridge',
    version='0.1.0',
    packages=[''],
    url='',
    license='MIT',
    author='meituanqa',
    author_email='',
    description='The Overbridge, sometimes called the War Room or Death Star Control Room, was the bridge and main command center of the first Death Star. The Overbridge was located above the battlestation\'s superlaser dish.',
    install_requires=[
    ]
)
